/** @jsx jsx */
import { ReactNode } from 'react';
import { GlobalSpacingToken } from '../constants';
import { BasePrimitiveProps, NonTextChildren } from './types';
interface InlineProps extends BasePrimitiveProps {
    /**
     * Used to align children along the cross axis.
     */
    alignItems?: FlexAlignItems;
    /**
     * Used to align children along the main axis.
     */
    justifyContent?: FlexJustifyContent;
    /**
     * Sets whether children are forced onto one line or can wrap onto multiple lines
     */
    flexWrap?: FlexWrap;
    /**
     * Token representing gap between children.
     */
    gap: GlobalSpacingToken;
    /**
     * Renders a divider between children.
     * If a string is provided it will automatically be wrapped in a `<Text>` component.
     */
    divider?: ReactNode;
    /**
     * Elements to be rendered inside the Inline.
     */
    children: NonTextChildren;
}
declare type FlexAlignItems = keyof typeof flexAlignItemsMap;
declare const flexAlignItemsMap: {
    center: import("@emotion/react").SerializedStyles;
    baseline: import("@emotion/react").SerializedStyles;
    flexStart: import("@emotion/react").SerializedStyles;
    flexEnd: import("@emotion/react").SerializedStyles;
    start: import("@emotion/react").SerializedStyles;
    end: import("@emotion/react").SerializedStyles;
};
declare type FlexJustifyContent = keyof typeof flexJustifyContentMap;
declare const flexJustifyContentMap: {
    center: import("@emotion/react").SerializedStyles;
    flexStart: import("@emotion/react").SerializedStyles;
    flexEnd: import("@emotion/react").SerializedStyles;
    start: import("@emotion/react").SerializedStyles;
    end: import("@emotion/react").SerializedStyles;
};
declare type FlexWrap = keyof typeof flexWrapMap;
declare const flexWrapMap: {
    wrap: import("@emotion/react").SerializedStyles;
};
/**
 * __Inline__
 *
 * Inline is a primitive component based on flexbox that manages the horizontal layout of direct children.
 * Renders a `div` by default.
 *
 */
declare const Inline: import("react").ForwardRefExoticComponent<InlineProps & import("react").RefAttributes<HTMLDivElement>>;
export default Inline;
/**
 * @codegenEnd
 */
