/// <reference types="react" />
import { GlobalSpacingToken } from '../constants';
import { BasePrimitiveProps, NonTextChildren } from './types';
interface StackProps extends BasePrimitiveProps {
    /**
     * Used to align children along the cross axis.
     */
    alignItems?: FlexAlignItems;
    /**
     * Used to align children along the main axis.
     */
    justifyContent?: FlexJustifyContent;
    /**
     * Sets whether children are forced onto one line or can wrap onto multiple lines
     */
    flexWrap?: FlexWrap;
    /**
     * Token representing gap between children.
     */
    gap: GlobalSpacingToken;
    /**
     * Elements to be rendered inside the Stack.
     */
    children: NonTextChildren;
}
declare type FlexAlignItems = keyof typeof flexAlignItemsMap;
declare const flexAlignItemsMap: {
    center: import("@emotion/react").SerializedStyles;
    baseline: import("@emotion/react").SerializedStyles;
    flexStart: import("@emotion/react").SerializedStyles;
    flexEnd: import("@emotion/react").SerializedStyles;
    start: import("@emotion/react").SerializedStyles;
    end: import("@emotion/react").SerializedStyles;
};
declare type FlexJustifyContent = keyof typeof flexJustifyContentMap;
declare const flexJustifyContentMap: {
    center: import("@emotion/react").SerializedStyles;
    flexStart: import("@emotion/react").SerializedStyles;
    flexEnd: import("@emotion/react").SerializedStyles;
    start: import("@emotion/react").SerializedStyles;
    end: import("@emotion/react").SerializedStyles;
};
declare type FlexWrap = keyof typeof flexWrapMap;
declare const flexWrapMap: {
    wrap: import("@emotion/react").SerializedStyles;
};
/**
 * __Stack__
 *
 * Stack is a primitive component based on flexbox that manages the vertical layout of direct children.
 * Renders a `div` by default.
 *
 */
declare const Stack: import("react").ForwardRefExoticComponent<StackProps & import("react").RefAttributes<HTMLDivElement>>;
export default Stack;
/**
 * @codegenEnd
 */
